@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2021-08-31 18:14:07
+@LastEditTime: 2022-02-17 09:23:51
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -237,11 +237,12 @@ class ActHandler(SevenBaseHandler):
         :param rule_desc：规则配置
         :param is_black：是否开启退款惩罚
         :param is_task：是否开启任务
+        :param exceed_tips: 超出次数提示内容
         :param refund_count：退款成功次数
         :param index_desc: 首页配置
         :param shakebox_tips: 摇盒提示配置
         :param shakebox_tips_num: 摇盒次数
-        :param exceed_tips: 超出次数提示内容
+        :param task_currency_type: 任务货币类型
         :return: 
         :last_editors: HuangJingCan
         """
@@ -260,6 +261,7 @@ class ActHandler(SevenBaseHandler):
         shakebox_tips = self.get_param("shakebox_tips")
         shakebox_tips_num = self.get_param("shakebox_tips_num", 0)
         exceed_tips = self.get_param("exceed_tips")
+        task_currency_type = self.get_param("task_currency_type")
 
         act_info_model = ActInfoModel(context=self)
         if act_id > 0:
@@ -280,6 +282,7 @@ class ActHandler(SevenBaseHandler):
             act_info.exceed_tips = exceed_tips
             act_info.is_black = is_black
             act_info.is_task = is_task
+            act_info.task_currency_type = task_currency_type
             act_info.refund_count = refund_count
             act_info.store_url = store_url
             act_info.modify_date = self.get_now_datetime()
